valueWidget property

Widget Function(String max)? valueWidget
final

An alternative to displaying the text value of the slider.

Defaults to null.

When used valueWidget will override the value for the selected value widget.

Implementation

final Widget Function(String value)? valueWidget;